@@ -8,9 +8,10 @@ import re
 from pathlib import Path
 from urllib.parse import unquote, urlparse, ParseResult
 import mistletoe
-from notion.block import ImageBlock, CollectionViewBlock, PageBlock
+from notion.block import EmbedOrUploadBlock, CollectionViewBlock, PageBlock
 from notion.client import NotionClient
-from .NotionPyRenderer import NotionPyRenderer, addHtmlImgTagExtension
+from .NotionPyRenderer import NotionPyRenderer, addHtmlImgTagExtension, addLatexExtension
+
 
 def relativePathForMarkdownUrl(url, mdFilePath):
     """
@@ -70,7 +71,10 @@ def uploadBlock(blockDescriptor, blockParent, mdFilePath, imagePathFunc=None):
         del blockDescriptor["children"]
     newBlock = blockParent.children.add_new(blockClass, **blockDescriptor)
     # Upload images to Notion.so that have local file paths
-    if isinstance(newBlock, ImageBlock):
+    # most of the time, this will be a standard ImageBlock; however some markdown
+    # generators use the image syntax for general purpose "embedded" files; hence we
+    # check for any subclass of EmbedOrUploadBlock (which provides upload_file)
+    if issubclass(blockClass, EmbedOrUploadBlock):
         imgRelSrc = blockDescriptor["source"]
         if re.search(r"(?<!file)://", imgRelSrc, re.I):
             return #Don't upload images that are external urls
@@ -178,12 +182,16 @@ def cli(argv):
     parser.set_defaults(mode='create')
     parser.add_argument('--html-img', action='store_true', default=False,
                         help="Upload images in HTML <img> tags (disabled by default)")
+    parser.add_argument('--latex', action='store_true', default=False,
+                        help="Support for latex inline ($..$) and block ($$..$$) equations (disabled by default)")
 
     args = parser.parse_args(argv)
 
     notionPyRendererCls = NotionPyRenderer
     if args.html_img:
         notionPyRendererCls = addHtmlImgTagExtension(notionPyRendererCls)
+    if args.latex:
+        notionPyRendererCls = addLatexExtension(notionPyRendererCls)
 
     print("Initializing Notion.so client...")
     client = NotionClient(token_v2=args.token_v2)
@@ -205,4 +213,4 @@ def cli(argv):
 
 
 if __name__ == "__main__":
-    cli(sys.argv[1:])
\ No newline at end of file
+    cli(sys.argv[1:])
